contacts.CompanyType (Organization type) — amici1

# `contacts.CompanyType` (Organization type)

CompanyType(id, name, abbr, abbr_de, abbr_fr, name_de, name_fr)

Master tables : contacts.CompanyTypes (Organization types)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Designation (name) : See `<lino.utils.mldbc.fields.BabelCharField: name>`.

- Abbreviation (abbr) : See `<lino.utils.mldbc.fields.BabelCharField: abbr>`.

- Abbreviation (de) (abbr_de) : See `<django.db.models.fields.CharField: abbr_de>`.

- Abbreviation (fr) (abbr_fr) : See `<django.db.models.fields.CharField: abbr_fr>`.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Name (name_column) : See `lino_xl.lib.contacts.models.CompanyType.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.contacts.models.CompanyType.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.contacts.models.CompanyType.overview`.

Referenced from contacts.Company.type

## Database fields

Internal name | Verbose name | Help text
id | ID |
name | Designation |
abbr | Abbreviation |
abbr_de | Abbreviation (de) |
abbr_fr | Abbreviation (fr) |
name_de | Designation (de) |
name_fr | Designation (fr) |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |